@@ -1,7 +1,5 @@
 
 
-from typing import Union
-
 from pydantic import Field
 from pydantic import HttpUrl
 from pydantic import validator
@@ -10,10 +8,6 @@ from pydantic import create_model
 from tendril.utils.pydantic import TendrilTBaseModel
 
 
-class UserReferenceTModel(TendrilTBaseModel):
-    user_id: Union[int, str] = Field(...)
-
-
 class UserStubTModel(TendrilTBaseModel):
     name: str = Field(..., example="User Full Name")
     nickname: str = Field(..., example="nickname")
